changeset 53401:3cf88b19f762

(define-generic-mode): Doc fix.
author Richard M. Stallman <rms@gnu.org>
date Mon, 29 Dec 2003 19:12:40 +0000
parents 01072e418fa4
children 7e645ea92195
files lisp/generic.el
diffstat 1 files changed, 2 insertions(+), 2 deletions(-) [+]
line wrap: on
line diff
--- a/lisp/generic.el	Mon Dec 29 19:12:17 2003 +0000
+++ b/lisp/generic.el	Mon Dec 29 19:12:40 2003 +0000
@@ -54,7 +54,7 @@
 ;;
 ;; * Additional expressions to font-lock.  This should be a list of
 ;;   expressions, each of which should be of the same form
 ;;   as those in `font-lock-defaults-alist'.
 ;;
 ;; * List of regular expressions to be placed in auto-mode-alist.
 ;;
@@ -206,7 +206,7 @@
 Each keyword should be a string.
 
 FONT-LOCK-LIST is a list of additional expressions to highlight. Each entry
-in the list should have the same form as an entry in `font-lock-defaults-alist'
+in the list should have the same form as an entry in `font-lock-keywords'.
 
 AUTO-MODE-LIST is a list of regular expressions to add to `auto-mode-alist'.
 These regexps are added to `auto-mode-alist' as soon as `define-generic-mode'
@@ -54,7 +54,7 @@
 ;; * Additional expressions to font-lock.  This should be a list of
 ;;   expressions, each of which should be of the same form
-;;   as those in `font-lock-defaults-alist'.
+;;   as those in `font-lock-keywords'.
 ;;
 ;; * List of regular expressions to be placed in auto-mode-alist.